aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorLuigi Yucheng LIU <luigi.liu@laposte.net>2014-08-25 23:33:34 +0800
committerMatthias P. Braendli <matthias.braendli@mpb.li>2014-08-27 18:37:47 +0200
commitbc8ae4b251056e630d2de525f9884980d79379d6 (patch)
tree60d5bf9c89fb014dd62bdea45125c7eb39c94621 /src
parenta0ed05ef05c1d464f45ebb05bf5351ee555148d7 (diff)
downloadODR-PadEnc-bc8ae4b251056e630d2de525f9884980d79379d6.tar.gz
ODR-PadEnc-bc8ae4b251056e630d2de525f9884980d79379d6.tar.bz2
ODR-PadEnc-bc8ae4b251056e630d2de525f9884980d79379d6.zip
Update mot-encoder.cpp
Diffstat (limited to 'src')
-rw-r--r--src/mot-encoder.cpp6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/mot-encoder.cpp b/src/mot-encoder.cpp
index 493c3d2..9eb28b8 100644
--- a/src/mot-encoder.cpp
+++ b/src/mot-encoder.cpp
@@ -59,6 +59,7 @@ extern "C" {
#define MAXSEGLEN 8179
#define MAXDLS 128 // limit defined in ETSI TS 102 980
#define MAXSLIDESIZE 50000
+#define MAXSLIDEID 9999
// Do not allow the image compressor to go below
// JPEG quality 40
@@ -95,7 +96,7 @@ struct slide_metadata_t {
// complete path to slide
std::string filepath;
// index, values from 0 to 9999, rolls over
int fidx;
// This is used to define the order in which several discovered
@@ -278,8 +279,9 @@ int main(int argc, char *argv[])
fprintf(stderr, "mot-encoder Error: cannot open directory '%s'\n", dir);
return 1;
}
- if (fidx == 9999) {
+ if (fidx == MAXSLIDEID) {
fidx = 0;
+ transmission_history.clear();
}
// Add new slides to transmit to list
@@ -95,7 +96,7 @@ struct slide_metadata_t {
// complete path to slide
std::string filepath;
- // index, values from 0 to 9999, rolls over
+ // index, values from 0 to MAXSLIDEID, rolls over
int fidx;
// This is used to define the order in which several discovered